pub enum ParseHashError {
MissingPrefix,
ParseError(ParseIntError),
}Variants
MissingPrefix
The error returned when the numeric hash string doesn’t begin with “0x”
ParseError(ParseIntError)
The error returned when the hexadecimal part of the hash string cannot be parsed